<?php

namespace QUI\Verification;

/**
 * VerificationInterface
 *
 * This interface must be implemented to start a verification process via Verifier::startVerification()
 */
interface VerificationInterface
{
    /**
     * Get a unique identifier that identifies this Verification
     *
     * @return string|int
     */
    public function getIdentifier(): string|int;

    /**
     * Set identifier that is unique to this verification.
     *
     * @param string|int $identifier
     * @return void
     */
    public function setIdentifier(string|int $identifier): void;

    /**
     * Get additional data
     *
     * @return array
     */
    public function getAdditionalData(): array;

    public function setAdditionalData(array $data): void;

    /**
     * Get the duration of a Verification (minutes)
     *
     * @return int|false - duration in minutes;
     * if this method returns false use the module setting default value
     */
    public function getValidDuration(): bool|int;

    /**
     * Execute this method on successful verification
     *
     * @return void
     */
    public function onSuccess(): void;

    /**
     * Execute this method on unsuccessful verification
     *
     * @return void
     */
    public function onError(): void;

    /**
     * This message is displayed to the user on successful verification
     *
     * @return string
     */
    public function getSuccessMessage(): string;

    /**
     * This message is displayed to the user on unsuccessful verification
     *
     * @param string $reason - The reason for the error (see \QUI\Verification\Verifier::REASON_*)
     * @return string
     */
    public function getErrorMessage(string $reason): string;

    /**
     * Automatically redirect the user to this URL on successful verification
     *
     * @return string|false - If this method returns false, no redirection takes place
     */
    public function getOnSuccessRedirectUrl(): bool|string;

    /**
     * Automatically redirect the user to this URL on unsuccessful verification
     *
     * @return string|false - If this method returns false, no redirection takes place
     */
    public function getOnErrorRedirectUrl(): bool|string;

    /**
     * Get type (class name)
     *
     * @return string
     */
    public static function getType(): string;
}
